tests Package
=============

:mod:`test_icons` Module
------------------------

.. automodule:: CMFDefault.browser.skins.tests.test_icons
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_ursa` Module
-----------------------

.. automodule:: CMFDefault.browser.skins.tests.test_ursa
    :members:
    :undoc-members:
    :show-inheritance:

